/*
LTC1298 Function File

*/
#include <propeller.h>
#include "ltc1298header.h"


static const int LTC1298_CH0 = 0b1101;						   // The address for CH0 return
static const int LTC1298_CH1 = 0b1111;						   // The address for CH1 return


static int LTC1298_cs, LTC1298_clk, LTC1298_data;						   // Pin address for function use


void setupLTC1298 (int cs, int clk, int data)
{

//Set Clk to output
SET(DIRA, clk);
//set cs to output
SET(DIRA, cs);
//Set to idel high
SET(OUTA, cs);

//Save cs, clk, data for later use
LTC1298_cs = cs;
LTC1298_clk = clk;
LTC1298_data = data;




}

int ltc1298GetAdcVal(int channel)
{
 
 if (channel == 0) // if Channel 0 is selected 
 {
 ltc1298ShiftOut(LTC1298_CH0);  // Send ch0 command
 }
 else
 {
 ltc1298ShiftOut(LTC1298_CH1);  // Else ch1 was called and send ch 1 command
 }
 
 return ltc1298ShiftIn(); // get the data and return it.
 
}

static void ltc1298ShiftOut(int val)
{

int counter;

// Make sure data is an output
SET(DIRA, LTC1298_data);

// Take CS low
CLR(OUTA, LTC1298_cs);

for(counter = 0; counter < 4; counter++)
{
// Make the clk low
CLR(OUTA, LTC1298_clk);	
	

// set the bit
 if ((val  & 0b1000) == 0b1000)// if the value to be shifted is a 1
 	{
	SET(OUTA, LTC1298_data);
	}
 else // the value is a 0
	{
	CLR(OUTA, LTC1298_data);
	}

// Make clock high
SET(OUTA, LTC1298_clk);
	
	//move val left 1 spot
	val = val << 1;	

}

// release data line while 4th input pin is high
CLR(DIRA, LTC1298_data);

// Make clock low 
CLR(OUTA, LTC1298_clk);

}

static int ltc1298ShiftIn(void)
{

int counter, result=0;
// Make sure clock is low to start
CLR(OUTA, LTC1298_clk);

// its to 13 because 1st bit is a null bit
for(counter = 0; counter < 13; counter++)
	{
	
	SET(OUTA, LTC1298_clk); // set clock high
	
	
	if (pinState(LTC1298_data) == 1) // return is a 1
	  {
	    result = (result << 1) + 1;
		//printf("Bit %d High %c", counter,13);
	  }
	else // return is a 0
	  {
	   result = result << 1;
	   
		//printf("Bit %d Low %c", counter,13);
	  }
	 
	 CLR(OUTA, LTC1298_clk); // Set clock low, data is valid on traling edge 
   }
SET(OUTA, LTC1298_cs); 

return result;
}


  /*
+------------------------------------------------------------------------------------------------------------------------------+
                                                   TERMS OF USE: MIT License                                                                                                              
+------------------------------------------------------------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation     
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         
+------------------------------------------------------------------------------------------------------------------------------+
*/
