/*

Header File for LTC1298 12 Bit ADC

By TJ Johnson

4/6/09

Valid Channels are 0 and 1.

Wireing for LTC1298 
Pin 1 - CS
Pin 2 - CH0 input
Pin 3 - CH1 input
Pin 4 - GND

Pin 5 - Data
Pin 6 - Data
Pin 7 - Clk
Pin 8 - Vcc
Pins 5 and 6 connected together.
WARNING : A 1k resitor must be placed between the prop and pins 5 & 6.

Outputs the current values to the terminal at baud 57600. 


*/


#ifndef __LTC1298__
#define __LTC1298__

#define pinState(pin) ((INA >> pin) & 1) // Get the current pin state

	

   // Name: setupLTC1298
   // Input: Cs pin, clk pin, data pin 
   // Output: None
   // Dependices: none
   // Process: Sets the pins to ouputs, sets CS to idel, saves pin nums to global
   	  //variables
void setupLTC1298 (int cs, int clk, int data); 


   // Name: ltc1298GetAdcVal
   // Input: Channel - 0 or 1 
   // Output: The current ADC value
   // Dependices: ltc1298ShiftOut, ltc1298ShiftIn
   // Process: Shifts out the correct mux address, then shifts in the current 12
   	  // bit adc value
int ltc1298GetAdcVal(int channel);					   


   // Name: ltc1298ShiftOut
   // Input: The 4 bit value to be shifted out 
   // Output: None
   // Dependices: none
   // Process: Brings Cs low, Shifts out the command value MSB 1st
static void ltc1298ShiftOut(int val);	   	   				   

   // Name: ltc1298ShiftIn
   // Input: None 
   // Output: The 12 bit adc value
   // Dependices: none
   // Process: Shifts in the 12 bit adc value MSB 1st.
static int ltc1298ShiftIn(void);							  


#endif 
